#
# spec file for package smcroute
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2018, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           smcroute
Version:        2.4.4
Release:        bp153.1.19
Summary:        Static multicast routing for UNIX
License:        GPL-3.0-only
Group:          Productivity/Networking/Routing
URL:            http://troglobit.com/projects/smcroute/
#Git-Clone:     https://github.com/troglobit/smcroute.git
Source:         https://github.com/troglobit/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(systemd)

%description
SMCRoute is a UNIX/Linux tool to manage and monitor multicast routes.
It supports both IPv4 and IPv6 multicast routing.

SMCRoute can be used as an alternative to dynamic multicast routers like
mrouted or pimd in setups where static multicast routes should be
maintained and/or no proper IGMP or MLD signaling exists.

Multicast routes exist in the UNIX kernel as long as a multicast routing
daemon runs. On Linux, multiple multicast routers can run simultaneously
using different multicast routing tables.

%prep
%setup -q
sed -i 's|@DOCDIR@|%{_docdir}/smcroute/|g' smcroute.service.in

# remove file not used by Linux with incompatible Apple license
rm src/ip_mroute.h

%build
autoreconf -fiv
%configure \
    --with-systemd \
    --disable-silent-rules
make %{?_smp_mflags}

%install
%make_install
install -Dm0644 smcroute.conf %{buildroot}/%{_sysconfdir}/smcroute.conf
rm -rf %{buildroot}/%{_datadir}/doc
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}.service
%service_add_pre %{name}.socket

%post
%service_add_post %{name}.service
%service_add_post %{name}.socket

%preun
%service_del_preun %{name}.service
%service_del_preun %{name}.socket

%postun
%service_del_postun %{name}.service
%service_del_postun %{name}.socket

%files
%doc README.md
%license COPYING
%{_sbindir}/smcroutectl
%{_sbindir}/smcrouted
%{_sbindir}/smcroute
%{_sbindir}/rcsmcroute
%config %{_sysconfdir}/smcroute.conf
%{_mandir}/man8/smcroute.8%{?ext_man}
%{_mandir}/man8/smcroutectl.8%{?ext_man}
%{_mandir}/man8/smcrouted.8%{?ext_man}
%{_unitdir}/%{name}.service

%changelog
* Tue Feb 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.4
  Changes
  * Allow same outbound interface as inbound for routes, only warn user
  * systemd unit file hardening, recommended by Debian
  Fixes
  * IGMP header checksum missing from mrdisc frames
  * Unblock *all* matching, and currently blocked, (S,G) to a
    newly installed (*,G) route, only the first know was unblocked
  * Timer nanosecond bug causing loss of address refresh on DHCP
    interfaces.  Interface monitoring feature introduced in v2.4.3
  * Calling init script with `stop` does not stop `smcrouted`
  * ifindex in UNIX/POSIX is an interger, not unsigned short
* Wed Nov 14 2018 Tomáš Chvátal <tchvatal@suse.com>
- Remove ip_route.h for the license clash
* Sat Nov 10 2018 mardnh@gmx.de
- Update to version 2.4.3
  Changes
  * Add strlcat() replacement from OpenBSD, use instead of strcat()
  * smcrouted should never log to system console, proposed by Westermo
  Fixes
  * smcrouted fails to join multicast groups on interfaces that do not
    yet have an IP address when smcrouted starts up, or when it receives
    SIGHUP, e.g. DHCP client interfaces. This patch release adds a timer
    refresh of interface addresses that retries multicast group joins
    until an address is set. This is similar to issue #55, but does not
    handle interfaces that do not exist yet.
  * Make sure Linux alias interfaces (baseif:num) are registered as
    baseif. Westermo found that use of alias interfaces cause multiple
    VIFs to be registered for the same base interface causing multicast
    routes to use the wrong inbound or outbound VIF. Alias interfaces
    use the same underlying physical interface so only one VIF needed.
  * Fix display of route counters and column alignment
  * Simplify utimensat() replacement, AT_SYMLINK_NOFOLLOW unused
* Mon Sep 10 2018 mardnh@gmx.de
- Update to version 2.4.2
  Changes
  * Add wrapper script smcroute for use with old style startup scripts
  * Add symlinks to man pages for smcrouted.8 and smcroutectl.8
  * Update SysV init script, daemon now called smcrouted
  Fixes
  * Fix #96: A .conf line may be missing final newline, this is fine
  * Spellcheck smcroute.conf example
* Mon Jun 18 2018 mardnh@gmx.de
- Initial package, version 2.4.1
